The XML files in this directory are the source files for the corresponding
SVG files in the ``source/_images`` directory. They were created with, and
can be edited using the free draw.io online service.
